package sdk

import (
	"io/ioutil"
	"net/http"
	"strings"
	"time"
)

type Client struct {
	apiUrl  	string
	serverName 	string
	requestId 	string
}

func NewClient() (client *Client, err error) {
	client = new(Client)
	return
}

func NewClientWithConfig(apiUrl, serverName, requestId string) (client *Client, err error) {
	client = &Client{
		apiUrl: apiUrl,
		serverName: serverName,
		requestId: requestId,
	}
	return
}

func (c *Client)Post(urlMethod string, params string) (res []byte, err error) {
	urlMethod = c.apiUrl + urlMethod
	req, err := http.NewRequest("POST", urlMethod, strings.NewReader(params))
	if err != nil {
		return
	}
	req.Header.Set("service_name", c.serverName)
	req.Header.Set("request_id", c.requestId)
	resp, err := (&http.Client{
		Timeout: time.Second * 30,//
	}).Do(req)
	if err != nil {
		return
	}
	res, _ = ioutil.ReadAll(resp.Body)
	err = resp.Body.Close()
	if err != nil {
		return
	}
	return
}

func (c *Client)Get(urlMethod string, params string) (res []byte, err error) {
	urlMethod = c.apiUrl + urlMethod
	req, err := http.NewRequest("GET", urlMethod, strings.NewReader(params))
	if err != nil {
		return
	}
	req.Header.Set("service_name", c.serverName)
	req.Header.Set("request_id", c.requestId)
	resp, err := (&http.Client{
		Timeout: time.Second * 30,//
	}).Do(req)
	if err != nil {
		return
	}
	res, _ = ioutil.ReadAll(resp.Body)
	err = resp.Body.Close()
	if err != nil {
		return
	}

	return
}

func (c *Client)Patch(urlMethod string, params string) (res []byte, err error) {
	urlMethod = c.apiUrl + urlMethod
	req, err := http.NewRequest("PATCH", urlMethod, strings.NewReader(string(params)))
	req.Header.Set("service_name", c.serverName)
	req.Header.Set("request_id", c.requestId)
	resp, err := (&http.Client{
		Timeout: time.Second * 30,//
	}).Do(req)
	if err != nil {
		return
	}
	res, _ = ioutil.ReadAll(resp.Body)
	err = resp.Body.Close()
	if err != nil {
		return
	}

	return
}

func (c *Client)PUT(urlMethod string, params string) (res []byte, err error) {
	urlMethod = c.apiUrl + urlMethod
	req, err := http.NewRequest("PUT", urlMethod, strings.NewReader(string(params)))
	req.Header.Set("service_name", c.serverName)
	req.Header.Set("request_id", c.requestId)
	resp, err := (&http.Client{
		Timeout: time.Second * 30,//
	}).Do(req)
	if err != nil {
		return
	}
	res, _ = ioutil.ReadAll(resp.Body)
	err = resp.Body.Close()
	if err != nil {
		return
	}

	return
}

func (c *Client)DELETE(urlMethod string, params string) (res []byte, err error) {
	urlMethod = c.apiUrl + urlMethod
	req, err := http.NewRequest("DELETE", urlMethod, strings.NewReader(string(params)))
	req.Header.Set("service_name", c.serverName)
	req.Header.Set("request_id", c.requestId)
	resp, err := (&http.Client{
		Timeout: time.Second * 30,//
	}).Do(req)
	if err != nil {
		return
	}
	res, _ = ioutil.ReadAll(resp.Body)
	err = resp.Body.Close()
	if err != nil {
		return
	}

	return
}